@@ -11,7 +11,7 @@
 #ifndef LIBRSS_GLOBAL_H
 #define LIBRSS_GLOBAL_H
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 template <class>
 class TQValueList;
