@@ -48,29 +48,29 @@ AtlanticDesigner::AtlanticDesigner(TQWidget *parent, const char *name)
 	board = 0;
 	layout = 0;
 
-	(void) KStdAction::quit(TQT_TQOBJECT(this), TQT_SLOT(close()), actionCollection());
-	(void) KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(open()), actionCollection());
-	(void) KStdAction::openNew(TQT_TQOBJECT(this), TQT_SLOT(openNew()), actionCollection());
-	(void) KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(save()), actionCollection());
-	(void) KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(saveAs()), actionCollection());
-	(void) new TDEAction(i18n("&Edit Gameboard Info..."), CTRL+Key_I, TQT_TQOBJECT(this), TQT_SLOT(info()), actionCollection(), "boardinfo");
-	(void) new TDEAction(i18n("&Edit Groups..."), CTRL+Key_G, TQT_TQOBJECT(this), TQT_SLOT(editGroups()), actionCollection(), "groupeditor");
+	(void) KStdAction::quit(this, TQ_SLOT(close()), actionCollection());
+	(void) KStdAction::open(this, TQ_SLOT(open()), actionCollection());
+	(void) KStdAction::openNew(this, TQ_SLOT(openNew()), actionCollection());
+	(void) KStdAction::save(this, TQ_SLOT(save()), actionCollection());
+	(void) KStdAction::saveAs(this, TQ_SLOT(saveAs()), actionCollection());
+	(void) new TDEAction(i18n("&Edit Gameboard Info..."), CTRL+Key_I, this, TQ_SLOT(info()), actionCollection(), "boardinfo");
+	(void) new TDEAction(i18n("&Edit Groups..."), CTRL+Key_G, this, TQ_SLOT(editGroups()), actionCollection(), "groupeditor");
 
-	(void) new TDEAction(i18n("&Add 4 Squares"), "zoom-in", 0, TQT_TQOBJECT(this), TQT_SLOT(larger()), actionCollection(), "larger");
-	(void) new TDEAction(i18n("&Remove 4 Squares"), "zoom-out", 0, TQT_TQOBJECT(this), TQT_SLOT(smaller()), actionCollection(), "smaller");
-	(void) KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(copy()), actionCollection());
-	(void) KStdAction::paste(TQT_TQOBJECT(this), TQT_SLOT(paste()), actionCollection());
-	(void) new TDEAction(i18n("&Up"), Key_Up, TQT_TQOBJECT(this), TQT_SLOT(up()), actionCollection(), "up");
-	(void) new TDEAction(i18n("&Down"), Key_Down, TQT_TQOBJECT(this), TQT_SLOT(down()), actionCollection(), "down");
-	(void) new TDEAction(i18n("&Left"), Key_Left, TQT_TQOBJECT(this), TQT_SLOT(left()), actionCollection(), "left");
-	(void) new TDEAction(i18n("&Right"), Key_Right, TQT_TQOBJECT(this), TQT_SLOT(right()), actionCollection(), "right");
+	(void) new TDEAction(i18n("&Add 4 Squares"), "zoom-in", 0, this, TQ_SLOT(larger()), actionCollection(), "larger");
+	(void) new TDEAction(i18n("&Remove 4 Squares"), "zoom-out", 0, this, TQ_SLOT(smaller()), actionCollection(), "smaller");
+	(void) KStdAction::copy(this, TQ_SLOT(copy()), actionCollection());
+	(void) KStdAction::paste(this, TQ_SLOT(paste()), actionCollection());
+	(void) new TDEAction(i18n("&Up"), Key_Up, this, TQ_SLOT(up()), actionCollection(), "up");
+	(void) new TDEAction(i18n("&Down"), Key_Down, this, TQ_SLOT(down()), actionCollection(), "down");
+	(void) new TDEAction(i18n("&Left"), Key_Left, this, TQ_SLOT(left()), actionCollection(), "left");
+	(void) new TDEAction(i18n("&Right"), Key_Right, this, TQ_SLOT(right()), actionCollection(), "right");
 
 	recentAct = KStdAction::openRecent(0, 0, actionCollection());
-	connect(recentAct, TQT_SIGNAL(urlSelected(const KURL &)), TQT_TQOBJECT(this), TQT_SLOT(openRecent(const KURL &)));
+	connect(recentAct, TQ_SIGNAL(urlSelected(const KURL &)), this, TQ_SLOT(openRecent(const KURL &)));
 	recentAct->loadEntries(TDEGlobal::config(), "Designer recent files");
 
 	estateAct = new TDEListAction(i18n("Change Estate"), 0, 0, 0, actionCollection(), "estate_num");
-	connect(estateAct, TQT_SIGNAL(activated(int)), TQT_SLOT(changeEstate(int)));
+	connect(estateAct, TQ_SIGNAL(activated(int)), TQ_SLOT(changeEstate(int)));
 
 	createGUI("atlantikdesignerui.rc");
 
@@ -137,9 +137,9 @@ void AtlanticDesigner::initBoard()
 	setCentralWidget(board);
 	layout = new TQVBoxLayout(board->centerWidget());
 	editor = new EstateEdit(&groups, &estates, &cards, board->centerWidget(), "Estate Editor");
-	connect(editor, TQT_SIGNAL(goChecked(int)), TQT_TQOBJECT(this), TQT_SLOT(goChanged(int)));
-	connect(editor, TQT_SIGNAL(updateBackground()), TQT_TQOBJECT(this), TQT_SLOT(updateBackground()));
-	connect(editor, TQT_SIGNAL(resized()), board, TQT_SLOT(slotResizeAftermath()));
+	connect(editor, TQ_SIGNAL(goChecked(int)), this, TQ_SLOT(goChanged(int)));
+	connect(editor, TQ_SIGNAL(updateBackground()), this, TQ_SLOT(updateBackground()));
+	connect(editor, TQ_SIGNAL(resized()), board, TQ_SLOT(slotResizeAftermath()));
 	layout->addWidget(editor);
 
 	editor->setReady(false);
@@ -159,7 +159,7 @@ void AtlanticDesigner::initToken()
 	
 	board->addToken(m_player);
 
-	connect(m_player, TQT_SIGNAL(changed(Player *)), board, TQT_SLOT(playerChanged(Player *)));
+	connect(m_player, TQ_SIGNAL(changed(Player *)), board, TQ_SLOT(playerChanged(Player *)));
 }
 
 void AtlanticDesigner::openNew()
@@ -184,7 +184,7 @@ void AtlanticDesigner::openNew()
 	groupsChanged();
 	updateBackground();
 
-	TQTimer::singleShot(500, TQT_TQOBJECT(this), TQT_SLOT(setPlayerAtBeginning()));
+	TQTimer::singleShot(500, this, TQ_SLOT(setPlayerAtBeginning()));
 	doCaption(false);
 }
 
@@ -198,8 +198,8 @@ ConfigEstate *AtlanticDesigner::newEstate(int i)
 	estate->setChanged(false);
 	estates.insert(i, estate);
 
-	connect(estate, TQT_SIGNAL(LMBClicked(Estate *)), TQT_TQOBJECT(this), TQT_SLOT(changeEstate(Estate *)));
-	connect(estate, TQT_SIGNAL(changed()), TQT_TQOBJECT(this), TQT_SLOT(modified()));
+	connect(estate, TQ_SIGNAL(LMBClicked(Estate *)), this, TQ_SLOT(changeEstate(Estate *)));
+	connect(estate, TQ_SIGNAL(changed()), this, TQ_SLOT(modified()));
 
 	board->addEstateView(estate);
 
@@ -486,8 +486,8 @@ void AtlanticDesigner::openFile(const TQString &filename)
 			estate->setPassMoney(passMoney);
 			estates.append(estate);
 
-			connect(estate, TQT_SIGNAL(LMBClicked(Estate *)), TQT_TQOBJECT(this), TQT_SLOT(changeEstate(Estate *)));
-			connect(estate, TQT_SIGNAL(changed()), TQT_TQOBJECT(this), TQT_SLOT(modified()));
+			connect(estate, TQ_SIGNAL(LMBClicked(Estate *)), this, TQ_SLOT(changeEstate(Estate *)));
+			connect(estate, TQ_SIGNAL(changed()), this, TQ_SLOT(modified()));
 			i++;
 		}
 		else if (parseMode == Parse_Cards)
@@ -545,7 +545,7 @@ void AtlanticDesigner::openFile(const TQString &filename)
 	updateBackground();
 	updateJumpMenu();
 
-	TQTimer::singleShot(500, TQT_TQOBJECT(this), TQT_SLOT(setPlayerAtBeginning()));
+	TQTimer::singleShot(500, this, TQ_SLOT(setPlayerAtBeginning()));
 	doCaption(false);
 }
 
@@ -895,7 +895,7 @@ void AtlanticDesigner::larger()
 	groupsChanged();
 	updateBackground();
 
-	TQTimer::singleShot(500, TQT_TQOBJECT(this), TQT_SLOT(setPlayerAtBeginning()));
+	TQTimer::singleShot(500, this, TQ_SLOT(setPlayerAtBeginning()));
 	doCaption(true);
 }
 
@@ -934,7 +934,7 @@ void AtlanticDesigner::smaller()
 	updateJumpMenu();
 	groupsChanged();
 	updateBackground();
-	TQTimer::singleShot(500, TQT_TQOBJECT(this), TQT_SLOT(setPlayerAtBeginning()));
+	TQTimer::singleShot(500, this, TQ_SLOT(setPlayerAtBeginning()));
 
 	doCaption(true);
 }
@@ -957,9 +957,9 @@ void AtlanticDesigner::editGroups()
 		groupEditor = new GroupEditor(&groups, this);
 		groupEditor->show();
 
-		connect(groupEditor, TQT_SIGNAL(changed()), TQT_TQOBJECT(this), TQT_SLOT(modified()));
-		connect(groupEditor, TQT_SIGNAL(update()), TQT_TQOBJECT(this), TQT_SLOT(groupsChanged()));
-		connect(groupEditor, TQT_SIGNAL(update()), editor, TQT_SLOT(groupsChanged()));
+		connect(groupEditor, TQ_SIGNAL(changed()), this, TQ_SLOT(modified()));
+		connect(groupEditor, TQ_SIGNAL(update()), this, TQ_SLOT(groupsChanged()));
+		connect(groupEditor, TQ_SIGNAL(update()), editor, TQ_SLOT(groupsChanged()));
 	}
 	else
 		groupEditor->raise();
@@ -1019,8 +1019,8 @@ void AtlanticDesigner::info()
 		boardInfoDlg = new BoardInfoDlg(true, &boardInfo, this, "Board Information", false);
 		boardInfoDlg->show();
 
-		connect(boardInfoDlg, TQT_SIGNAL(okClicked()), TQT_TQOBJECT(this), TQT_SLOT(updateBackground()));
-		connect(boardInfoDlg, TQT_SIGNAL(okClicked()), TQT_TQOBJECT(this), TQT_SLOT(modified()));
+		connect(boardInfoDlg, TQ_SIGNAL(okClicked()), this, TQ_SLOT(updateBackground()));
+		connect(boardInfoDlg, TQ_SIGNAL(okClicked()), this, TQ_SLOT(modified()));
 	}
 	else
 		boardInfoDlg->raise();
