@@ -19,7 +19,7 @@ class TrollProjectWigdet;
 
 class CreateScopeDlg : public CreateScopeDlgBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
