@@ -105,7 +105,7 @@ bool QDesignerAction::addTo( TQWidget *w )
     if ( !widgetToInsert )
 	return TQAction::addTo( w );
 
-    if ( ::tqqt_cast<TQPopupMenu*>(w) )
+    if ( ::tqt_cast<TQPopupMenu*>(w) )
 	return FALSE;
 
     widgetToInsert->reparent( w, TQPoint( 0, 0 ), FALSE );
@@ -127,23 +127,23 @@ void QDesignerAction::remove()
 {
     if ( !widgetToInsert )
 	return;
-    MainWindow::self->formWindow()->selectWidget( TQT_TQOBJECT(widgetToInsert), FALSE );
+    MainWindow::self->formWindow()->selectWidget( widgetToInsert, FALSE );
     widgetToInsert->reparent( 0, TQPoint( 0, 0 ), FALSE );
 }
 
-QDesignerToolBarSeparator::QDesignerToolBarSeparator(Qt::Orientation o , TQToolBar *parent,
+QDesignerToolBarSeparator::QDesignerToolBarSeparator(TQt::Orientation o , TQToolBar *parent,
                                      const char* name )
     : TQWidget( parent, name )
 {
-    connect( parent, TQT_SIGNAL(orientationChanged(Qt::Orientation)),
-             this, TQT_SLOT(setOrientation(Qt::Orientation)) );
+    connect( parent, TQ_SIGNAL(orientationChanged(TQt::Orientation)),
+             this, TQ_SLOT(setOrientation(TQt::Orientation)) );
     setOrientation( o );
     setBackgroundMode( parent->backgroundMode() );
     setBackgroundOrigin( ParentOrigin );
     setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Minimum ) );
 }
 
-void QDesignerToolBarSeparator::setOrientation( Qt::Orientation o )
+void QDesignerToolBarSeparator::setOrientation( TQt::Orientation o )
 {
     orient = o;
 }
@@ -157,7 +157,7 @@ TQSize QDesignerToolBarSeparator::sizeHint() const
 {
     int extent = style().pixelMetric( TQStyle::PM_DockWindowSeparatorExtent,
 				      this );
-    if ( orient ==Qt::Horizontal )
+    if ( orient ==TQt::Horizontal )
 	return TQSize( extent, 0 );
     else
 	return TQSize( 0, extent );
@@ -168,10 +168,10 @@ void QDesignerToolBarSeparator::paintEvent( TQPaintEvent * )
     TQPainter p( this );
     TQStyle::SFlags flags = TQStyle::Style_Default;
 
-    if ( orientation() ==Qt::Horizontal )
+    if ( orientation() ==TQt::Horizontal )
 	flags |= TQStyle::Style_Horizontal;
 
-    style().tqdrawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
+    style().drawPrimitive( TQStyle::PE_DockWindowSeparator, &p, rect(),
 			   colorGroup(), flags );
 }
 
@@ -184,11 +184,11 @@ QSeparatorAction::QSeparatorAction( TQObject *parent )
 
 bool QSeparatorAction::addTo( TQWidget *w )
 {
-    if ( ::tqqt_cast<TQToolBar*>(w) ) {
+    if ( ::tqt_cast<TQToolBar*>(w) ) {
 	TQToolBar *tb = (TQToolBar*)w;
 	wid = new QDesignerToolBarSeparator( tb->orientation(), tb );
 	return TRUE;
-    } else if ( ::tqqt_cast<TQPopupMenu*>(w) ) {
+    } else if ( ::tqt_cast<TQPopupMenu*>(w) ) {
 	idx = ( (TQPopupMenu*)w )->count();
 	( (TQPopupMenu*)w )->insertSeparator( idx );
 	return TRUE;
@@ -198,10 +198,10 @@ bool QSeparatorAction::addTo( TQWidget *w )
 
 bool QSeparatorAction::removeFrom( TQWidget *w )
 {
-    if ( ::tqqt_cast<TQToolBar*>(w) ) {
+    if ( ::tqt_cast<TQToolBar*>(w) ) {
 	delete wid;
 	return TRUE;
-    } else if ( ::tqqt_cast<TQPopupMenu*>(w) ) {
+    } else if ( ::tqt_cast<TQPopupMenu*>(w) ) {
 	( (TQPopupMenu*)w )->removeItemAt( idx );
 	return TRUE;
     }
@@ -221,7 +221,7 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw )
     insertAnchor = 0;
     afterAnchor = TRUE;
     setAcceptDrops( TRUE );
-    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
+    MetaDataBase::addEntry( this );
     lastIndicatorPos = TQPoint( -1, -1 );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
@@ -239,7 +239,7 @@ QDesignerToolBar::QDesignerToolBar( TQMainWindow *mw, Dock dock )
     setAcceptDrops( TRUE );
     indicator = new QDesignerIndicatorWidget( this );
     indicator->hide();
-    MetaDataBase::addEntry( TQT_TQOBJECT(this) );
+    MetaDataBase::addEntry( this );
     installEventFilter( this );
     widgetInserting = FALSE;
     findFormWindow();
@@ -250,7 +250,7 @@ void QDesignerToolBar::findFormWindow()
 {
     TQWidget *w = this;
     while ( w ) {
-	formWindow = ::tqqt_cast<FormWindow*>(w);
+	formWindow = ::tqt_cast<FormWindow*>(w);
 	if ( formWindow )
 	    break;
 	w = w->parentWidget();
@@ -260,11 +260,11 @@ void QDesignerToolBar::findFormWindow()
 void QDesignerToolBar::addAction( TQAction *a )
 {
     actionList.append( a );
-    connect( a, TQT_SIGNAL( destroyed() ), this, TQT_SLOT( actionRemoved() ) );
-    if ( ::tqqt_cast<TQActionGroup*>(a) ) {
+    connect( a, TQ_SIGNAL( destroyed() ), this, TQ_SLOT( actionRemoved() ) );
+    if ( ::tqt_cast<TQActionGroup*>(a) ) {
 	( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
 	actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
-    } else if ( ::tqqt_cast<QSeparatorAction*>(a) ) {
+    } else if ( ::tqt_cast<QSeparatorAction*>(a) ) {
 	( (QSeparatorAction*)a )->widget()->installEventFilter( this );
 	actionMap.insert( ( (QSeparatorAction*)a )->widget(), a );
     } else {
@@ -275,22 +275,22 @@ void QDesignerToolBar::addAction( TQAction *a )
 
 static void fixObject( TQObject *&o )
 {
-    while ( o && o->parent() && !::tqqt_cast<QDesignerToolBar*>(o->parent()) )
+    while ( o && o->parent() && !::tqt_cast<QDesignerToolBar*>(o->parent()) )
 	o = o->parent();
 }
 
 bool QDesignerToolBar::eventFilter( TQObject *o, TQEvent *e )
 {
-    if ( !o || !e || o->inherits( TQDOCKWINDOWHANDLE_OBJECT_NAME_STRING ) || o->inherits( "TQDockWindowTitleBar" ) )
+    if ( !o || !e || o->inherits( "TQDockWindowHandle" ) || o->inherits( "TQDockWindowTitleBar" ) )
 	return TQToolBar::eventFilter( o, e );
 
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) && e->type() == TQEvent::MouseButtonPress &&
-	 ( ( TQMouseEvent*)e )->button() == Qt::LeftButton ) {
+    if ( o == this && e->type() == TQEvent::MouseButtonPress &&
+	 ( ( TQMouseEvent*)e )->button() == TQt::LeftButton ) {
 	mousePressEvent( (TQMouseEvent*)e );
 	return TRUE;
     }
 
-    if ( TQT_BASE_OBJECT(o) == TQT_BASE_OBJECT(this) )
+    if ( o == this )
 	return TQToolBar::eventFilter( o, e );
 
     if ( e->type() == TQEvent::MouseButtonPress ) {
@@ -359,7 +359,7 @@ void QDesignerToolBar::contextMenuEvent( TQContextMenuEvent *e )
 void QDesignerToolBar::mousePressEvent( TQMouseEvent *e )
 {
     widgetInserting = FALSE;
-    if ( e->button() == Qt::LeftButton &&
+    if ( e->button() == TQt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL &&
 	 MainWindow::self->currentTool() != CONNECT_TOOL &&
@@ -393,7 +393,7 @@ void QDesignerToolBar::buttonContextMenuEvent( TQContextMenuEvent *e, TQObject *
     const int ID_SEP = 2;
     const int ID_DELTOOLBAR = 3;
     TQMap<TQWidget*, TQAction*>::Iterator it = actionMap.find( (TQWidget*)o );
-    if ( it != actionMap.end() && ::tqqt_cast<QSeparatorAction*>(*it) )
+    if ( it != actionMap.end() && ::tqt_cast<QSeparatorAction*>(*it) )
 	menu.insertItem( i18n( "Delete Separator" ), ID_DELETE );
     else
 	menu.insertItem( i18n( "Delete Item" ), ID_DELETE );
@@ -440,10 +440,10 @@ void QDesignerToolBar::buttonMousePressEvent( TQMouseEvent *e, TQObject * )
 {
     widgetInserting = FALSE;
 
-    if ( e->button() == Qt::MidButton )
+    if ( e->button() == TQt::MidButton )
 	return;
 
-    if ( e->button() == Qt::LeftButton &&
+    if ( e->button() == TQt::LeftButton &&
 	 MainWindow::self->currentTool() != POINTER_TOOL &&
 	 MainWindow::self->currentTool() != ORDER_TOOL &&
 	 MainWindow::self->currentTool() != CONNECT_TOOL &&
@@ -474,7 +474,7 @@ void QDesignerToolBar::removeWidget( TQWidget *w )
 
 void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
 {
-    if ( widgetInserting || ( e->state() & Qt::LeftButton ) == 0 )
+    if ( widgetInserting || ( e->state() & TQt::LeftButton ) == 0 )
 	return;
     if ( TQABS( TQPoint( dragStartPos - e->pos() ).manhattanLength() ) < TQApplication::startDragDistance() )
 	return;
@@ -494,13 +494,13 @@ void QDesignerToolBar::buttonMouseMoveEvent( TQMouseEvent *e, TQObject *o )
     TQApplication::sendPostedEvents();
     adjustSize();
 
-    TQString type = ::tqqt_cast<TQActionGroup*>(a) ? TQString( "application/x-designer-actiongroup" ) :
-	::tqqt_cast<QSeparatorAction*>(a) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
+    TQString type = ::tqt_cast<TQActionGroup*>(a) ? TQString( "application/x-designer-actiongroup" ) :
+	::tqt_cast<QSeparatorAction*>(a) ? TQString( "application/x-designer-separator" ) : TQString( "application/x-designer-actions" );
     TQStoredDrag *drag = new ActionDrag( type, a, this );
     drag->setPixmap( a->iconSet().pixmap() );
-    if ( ::tqqt_cast<QDesignerAction*>(a) ) {
+    if ( ::tqt_cast<QDesignerAction*>(a) ) {
 	if ( formWindow->widgets()->find( ( (QDesignerAction*)a )->widget() ) )
-	    formWindow->selectWidget( ( TQT_TQOBJECT(( (QDesignerAction*)a )->widget())), FALSE );
+	    formWindow->selectWidget( ( ( (QDesignerAction*)a )->widget()), FALSE );
     }
     if ( !drag->drag() ) {
 	AddActionToToolBarCommand *cmd = new AddActionToToolBarCommand( i18n( "Add Action '%1' to Toolbar '%2'" ).
@@ -555,11 +555,11 @@ void QDesignerToolBar::dropEvent( TQDropEvent *e )
     if ( e->provides( "application/x-designer-actions" ) ||
 	 e->provides( "application/x-designer-separator" ) ) {
 	if ( e->provides( "application/x-designer-actions" ) )
-	    a = ::tqqt_cast<QDesignerAction*>(ActionDrag::action());
+	    a = ::tqt_cast<QDesignerAction*>(ActionDrag::action());
 	else
-	    a = ::tqqt_cast<QSeparatorAction*>(ActionDrag::action());
+	    a = ::tqt_cast<QSeparatorAction*>(ActionDrag::action());
     } else {
-	a = ::tqqt_cast<QDesignerActionGroup*>(ActionDrag::action());
+	a = ::tqt_cast<QDesignerActionGroup*>(ActionDrag::action());
     }
 
     if ( actionList.findRef( a ) != -1 ) {
@@ -588,14 +588,14 @@ void QDesignerToolBar::reInsert()
     clear();
     for ( a = actionList.first(); a; a = actionList.next() ) {
 	a->addTo( this );
-	if ( ::tqqt_cast<TQActionGroup*>(a) ) {
+	if ( ::tqt_cast<TQActionGroup*>(a) ) {
 	    actionMap.insert( ( (QDesignerActionGroup*)a )->widget(), a );
 	    if ( ( (QDesignerActionGroup*)a )->widget() )
 		( (QDesignerActionGroup*)a )->widget()->installEventFilter( this );
-	} else if ( ::tqqt_cast<QDesignerAction*>(a) ) {
+	} else if ( ::tqt_cast<QDesignerAction*>(a) ) {
 	    actionMap.insert( ( (QDesignerAction*)a )->widget(), a );
 	    ( (QDesignerAction*)a )->widget()->installEventFilter( this );
-	} else if ( ::tqqt_cast<QSeparatorAction*>(a) ) {
+	} else if ( ::tqt_cast<QSeparatorAction*>(a) ) {
 	    actionMap.insert( ( (QSeparatorAction*)a )->widget(), a );
 	    ( (QSeparatorAction*)a )->widget()->installEventFilter( this );
 	}
@@ -611,7 +611,7 @@ void QDesignerToolBar::actionRemoved()
 
 TQPoint QDesignerToolBar::calcIndicatorPos( const TQPoint &pos )
 {
-    if ( orientation() ==Qt::Horizontal ) {
+    if ( orientation() ==TQt::Horizontal ) {
 	TQPoint pnt( width() - 2, 0 );
 	insertAnchor = 0;
 	afterAnchor = TRUE;
@@ -665,7 +665,7 @@ void QDesignerToolBar::drawIndicator( const TQPoint &pos )
     if ( lastIndicatorPos == pos )
 	return;
     bool wasVsisible = indicator->isVisible();
-    if ( orientation() ==Qt::Horizontal ) {
+    if ( orientation() ==TQt::Horizontal ) {
 	indicator->resize( 3, height() );
 	if ( pos != TQPoint( -1, -1 ) )
 	     indicator->move( pos.x() - 1, 0 );
@@ -709,7 +709,7 @@ void QDesignerToolBar::doInsertWidget( const TQPoint &p )
 void QDesignerToolBar::clear()
 {
     for ( TQAction *a = actionList.first(); a; a = actionList.next() ) {
-	if ( ::tqqt_cast<QDesignerAction*>(a) )
+	if ( ::tqt_cast<QDesignerAction*>(a) )
 	    ( (QDesignerAction*)a )->remove();
     }
     TQToolBar::clear();
@@ -719,7 +719,7 @@ void QDesignerToolBar::installEventFilters( TQWidget *w )
 {
     if ( !w )
 	return;
-    TQObjectList *l = w->queryList( TQWIDGET_OBJECT_NAME_STRING );
+    TQObjectList *l = w->queryList( "TQWidget" );
     for ( TQObject *o = l->first(); o; o = l->next() )
 	o->installEventFilter( this );
     delete l;
