@@ -52,12 +52,12 @@
 EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
     : EditFunctionsBase( parent, 0, TRUE ), formWindow( fw )
 {
-    connect( helpButton, TQT_SIGNAL( clicked() ), MainWindow::self, TQT_SLOT( showDialogHelp() ) );
+    connect( helpButton, TQ_SIGNAL( clicked() ), MainWindow::self, TQ_SLOT( showDialogHelp() ) );
 
     id = 0;
     functList.clear();
 
-    TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( TQT_TQOBJECT(fw) );
+    TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( fw );
     for ( TQValueList<MetaDataBase::Function>::Iterator it = functionList.begin(); it != functionList.end(); ++it ) {
 	TQListViewItem *i = new TQListViewItem( functionListView );
 
@@ -86,7 +86,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
 	id++;
 
 	if ( (*it).type == "slot" ) {
-	    if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( (*it).function ).latin1() ) )
+	    if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( (*it).function ).latin1() ) )
 		i->setText( 5, i18n( "Yes" ) );
 	    else
 		i->setText( 5, i18n( "No" ) );
@@ -96,7 +96,7 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
     }
 
     boxProperties->setEnabled( FALSE );
-    functionName->setValidator( new AsciiValidator( TRUE, TQT_TQOBJECT(functionName) ) );
+    functionName->setValidator( new AsciiValidator( TRUE, functionName ) );
 
     if ( functionListView->firstChild() )
 	functionListView->setCurrentItem( functionListView->firstChild() );
@@ -111,27 +111,27 @@ EditFunctions::EditFunctions( TQWidget *parent, FormWindow *fw, bool justSlots )
 
     // Connect listview signal to signal-relay
     TQObject::connect( functionListView,
-		      TQT_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString & ) ),
+		      TQ_SIGNAL( itemRenamed( TQListViewItem*, int, const TQString & ) ),
 		      this,
-		      TQT_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
+		      TQ_SLOT( emitItemRenamed(TQListViewItem*, int, const TQString&) ) );
 
     // Connect signal-relay to TQLineEdit "functionName"
-    TQObjectList *l = parent->queryList( TQLINEEDIT_OBJECT_NAME_STRING, "functionName" );
+    TQObjectList *l = parent->queryList( "TQLineEdit", "functionName" );
     TQObject *obj;
     TQObjectListIt itemsLineEditIt( *l );
     while ( (obj = itemsLineEditIt.current()) != 0 ) {
         ++itemsLineEditIt;
 	TQObject::connect( this,
-			  TQT_SIGNAL( itemRenamed( const TQString & ) ),
+			  TQ_SIGNAL( itemRenamed( const TQString & ) ),
 			  obj,
-			  TQT_SLOT( setText( const TQString & ) ) );
+			  TQ_SLOT( setText( const TQString & ) ) );
     }
     delete l;
 }
 
 void EditFunctions::okClicked()
 {
-    TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( TQT_TQOBJECT(formWindow) );
+    TQValueList<MetaDataBase::Function> functionList = MetaDataBase::functionList( formWindow );
     TQString n = i18n( "Add/Remove functions of '%1'" ).arg( formWindow->name() );
     TQPtrList<Command> commands;
     TQValueList<MetaDataBase::Function>::Iterator fit;
@@ -291,7 +291,7 @@ void EditFunctions::functionAdd( const TQString &access, const TQString &type )
 
     if ( i->text( 4 ) == "slot" ) {
 	i->setText( 0, "newSlot()" );
-	if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), "newSlot()" ) )
+	if ( MetaDataBase::isSlotUsed( formWindow, "newSlot()" ) )
 	    i->setText( 5, i18n( "Yes" ) );
 	else
 	    i->setText( 5, i18n( "No" ) );
@@ -398,7 +398,7 @@ void EditFunctions::currentTextChanged( const TQString &txt )
     functionListView->currentItem()->setText( 0, txt );
 
     if ( functionListView->currentItem()->text( 4 ) == "slot" ) {
-	if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( txt.latin1() ).latin1() ) )
+	if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( txt.latin1() ).latin1() ) )
 	    functionListView->currentItem()->setText( 5, i18n( "Yes" ) );
 	else
 	    functionListView->currentItem()->setText( 5, i18n( "No" ) );
@@ -441,7 +441,7 @@ void EditFunctions::currentTypeChanged( const TQString &type )
     lastType = type;
     functionListView->currentItem()->setText( 4, type );
     if ( type == "slot" ) {
-	if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow),
+	if ( MetaDataBase::isSlotUsed( formWindow,
 		MetaDataBase::normalizeFunction( functionListView->currentItem()->text( 0 ).latin1() ).latin1() ) )
 	    functionListView->currentItem()->setText( 5, i18n( "Yes" ) );
 	else
@@ -515,7 +515,7 @@ void EditFunctions::displaySlots( bool justSlots )
 	i->setText( 4, (*it).type );
 
 	if ( (*it).type == "slot" ) {
-	    if ( MetaDataBase::isSlotUsed( TQT_TQOBJECT(formWindow), MetaDataBase::normalizeFunction( (*it).newName ).latin1() ) )
+	    if ( MetaDataBase::isSlotUsed( formWindow, MetaDataBase::normalizeFunction( (*it).newName ).latin1() ) )
 		i->setText( 5, i18n( "Yes" ) );
 	    else
 		i->setText( 5, i18n( "No" ) );
