@@ -105,7 +105,7 @@ FITSViewer::FITSViewer (const KURL *url, TQWidget *parent, const char *name)
     history->setUndoLimit(10);
     history->setRedoLimit(10);
     history->documentSaved();
-    connect(history, TQT_SIGNAL(documentRestored()), this, TQT_SLOT(fitsRestore()));
+    connect(history, TQ_SIGNAL(documentRestored()), this, TQ_SLOT(fitsRestore()));
     
     /* Setup image widget */    
     image = new FITSImage(this);
@@ -131,39 +131,39 @@ FITSViewer::FITSViewer (const KURL *url, TQWidget *parent, const char *name)
     
     if (KSUtils::openDataFile( tempFile, "imgreduction.png" ) )
     {
-    	new TDEAction( i18n("Image Reduction"), tempFile.name(), TDEShortcut( "Ctrl+R" ), TQT_TQOBJECT(this), TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
+    	new TDEAction( i18n("Image Reduction"), tempFile.name(), TDEShortcut( "Ctrl+R" ), this, TQ_SLOT( imageReduction()), actionCollection(), "image_reduce");
 	tempFile.close();
     }
     else
-    	new TDEAction( i18n("Image Reduction"), "blend", TDEShortcut( "Ctrl+R" ), TQT_TQOBJECT(this), TQT_SLOT( imageReduction()), actionCollection(), "image_reduce");
+    	new TDEAction( i18n("Image Reduction"), "blend", TDEShortcut( "Ctrl+R" ), this, TQ_SLOT( imageReduction()), actionCollection(), "image_reduce");
 	
     /*if (KSUtils::openDataFile( tempFile, "bricon.png" ) )
     {
-    	new TDEAction( i18n("Brightness/Contrast"), tempFile.name(), TDEShortcut( "Ctrl+T" ), TQT_TQOBJECT(this), TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
+    	new TDEAction( i18n("Brightness/Contrast"), tempFile.name(), TDEShortcut( "Ctrl+T" ), this, TQ_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
 	tempFile.close();
     }
     else*/
-       	new TDEAction( i18n("Brightness/Contrast"), "contrast+", TDEShortcut( "Ctrl+T" ), TQT_TQOBJECT(this), TQT_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
+       	new TDEAction( i18n("Brightness/Contrast"), "contrast+", TDEShortcut( "Ctrl+T" ), this, TQ_SLOT( BrightContrastDlg()), actionCollection(), "image_brightness_contrast");
 	
     if (KSUtils::openDataFile( tempFile, "histogram.png" ) )
     {
-    	new TDEAction ( i18n("Histogram"), tempFile.name(), TDEShortcut("Ctrl+H"), TQT_TQOBJECT(this), TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
+    	new TDEAction ( i18n("Histogram"), tempFile.name(), TDEShortcut("Ctrl+H"), this, TQ_SLOT (imageHistogram()), actionCollection(), "image_histogram");
 	tempFile.close();
     }
     else
-        new TDEAction ( i18n("Histogram"), "wizard", TDEShortcut("Ctrl+H"), TQT_TQOBJECT(this), TQT_SLOT (imageHistogram()), actionCollection(), "image_histogram");
+        new TDEAction ( i18n("Histogram"), "wizard", TDEShortcut("Ctrl+H"), this, TQ_SLOT (imageHistogram()), actionCollection(), "image_histogram");
     
-    KStdAction::open(TQT_TQOBJECT(this), TQT_SLOT(fileOpen()), actionCollection());   
-    KStdAction::save(TQT_TQOBJECT(this), TQT_SLOT(fileSave()), actionCollection());
-    KStdAction::saveAs(TQT_TQOBJECT(this), TQT_SLOT(fileSaveAs()), actionCollection());
-    KStdAction::close(TQT_TQOBJECT(this), TQT_SLOT(slotClose()), actionCollection());
-    KStdAction::copy(TQT_TQOBJECT(this), TQT_SLOT(fitsCOPY()), actionCollection());
-    KStdAction::zoomIn(TQT_TQOBJECT(image), TQT_SLOT(fitsZoomIn()), actionCollection());
-    KStdAction::zoomOut(TQT_TQOBJECT(image), TQT_SLOT(fitsZoomOut()), actionCollection());
+    KStdAction::open(this, TQ_SLOT(fileOpen()), actionCollection());   
+    KStdAction::save(this, TQ_SLOT(fileSave()), actionCollection());
+    KStdAction::saveAs(this, TQ_SLOT(fileSaveAs()), actionCollection());
+    KStdAction::close(this, TQ_SLOT(slotClose()), actionCollection());
+    KStdAction::copy(this, TQ_SLOT(fitsCOPY()), actionCollection());
+    KStdAction::zoomIn(image, TQ_SLOT(fitsZoomIn()), actionCollection());
+    KStdAction::zoomOut(image, TQ_SLOT(fitsZoomOut()), actionCollection());
     new TDEAction( i18n( "&Default Zoom" ), "viewmagfit.png", TDEShortcut( "Ctrl+D" ),
-		TQT_TQOBJECT(image), TQT_SLOT(fitsZoomDefault()), actionCollection(), "zoom_default" );
-    new TDEAction( i18n( "Statistics"), "sum", 0, TQT_TQOBJECT(this), TQT_SLOT(fitsStatistics()), actionCollection(), "image_stats");
-    new TDEAction( i18n( "FITS Header"), "frame_spreadsheet.png", 0, TQT_TQOBJECT(this), TQT_SLOT(fitsHeader()), actionCollection(), "fits_editor");
+		image, TQ_SLOT(fitsZoomDefault()), actionCollection(), "zoom_default" );
+    new TDEAction( i18n( "Statistics"), "sum", 0, this, TQ_SLOT(fitsStatistics()), actionCollection(), "image_stats");
+    new TDEAction( i18n( "FITS Header"), "frame_spreadsheet.png", 0, this, TQ_SLOT(fitsHeader()), actionCollection(), "fits_editor");
     
    /* Create GUI */
    createGUI("fitsviewer.rc");
@@ -557,7 +557,7 @@ void FITSViewer::fileSave()
 	
 	if (TQFile::exists(currentURL.path()))
         {
-            int r=KMessageBox::warningContinueCancel(TQT_TQWIDGET(parent()),
+            int r=KMessageBox::warningContinueCancel(static_cast<TQWidget*>(parent()),
             i18n( "A file named \"%1\" already exists. "
                   "Overwrite it?" ).arg(currentURL.fileName()),
             i18n( "Overwrite File?" ),
