@@ -31,7 +31,7 @@
 class QueryManager;
 class GroupOptions;
 
-class KDE_EXPORT SettingsProfile
+class TDE_EXPORT SettingsProfile
 {
 public:
   SettingsProfile();
@@ -43,7 +43,7 @@ public:
   TQString block_set;
 };
 
-class KDE_EXPORT ProfilesDialog : public KDialogBase
+class TDE_EXPORT ProfilesDialog : public KDialogBase
 {
   TQ_OBJECT
   
