@@ -594,7 +594,7 @@ void Driver::setupLexer( Lexer * lexer ) {
   lexer->addSkipWord( "EXPORT_DOCKCLASS" );
   lexer->addSkipWord( "K_EXPORT_COMPONENT_FACTORY", SkipWordAndArguments );
   lexer->addSkipWord( "K_SYCOCAFACTORY", SkipWordAndArguments );
-  lexer->addSkipWord( "KDE_DEPRECATED" );
+  lexer->addSkipWord( "TDE_DEPRECATED" );
 
   // qt
   lexer->addSkipWord( "TQ_OBJECT" );
@@ -614,8 +614,6 @@ void Driver::setupLexer( Lexer * lexer ) {
   lexer->addSkipWord( "TQ_REFCOUNT" );
   lexer->addSkipWord( "TQ_EXPLICIT" );
   lexer->addSkipWord( "QMAC_PASCAL" );
-  lexer->addSkipWord( "QT_STATIC_CONST" );
-  lexer->addSkipWord( "QT_STATIC_CONST_IMPL" );
   lexer->addSkipWord( "TQT_WIN_PAINTER_MEMBERS" );
   lexer->addSkipWord( "TQT_NC_MSGBOX" );
   lexer->addSkipWord( "TQ_VARIANT_AS", SkipWordAndArguments );
