@@ -25,7 +25,7 @@
 
 #include <tqstring.h>
 #include <tqobject.h>
-#include <kdemacros.h>
+#include <tdemacros.h>
 class KPlayer;
 class KGame;
 class TDEProcess;
@@ -52,7 +52,7 @@ class TDEProcess;
  *
  *  @author Martin Heni <martin@heni-online.de>
  */
-class KDE_EXPORT KGameIO : public TQObject
+class TDE_EXPORT KGameIO : public TQObject
 {
   TQ_OBJECT
   
@@ -175,7 +175,7 @@ private:
  *  from a widget and create moves for the player it belongs to.
  *  @author Martin Heni <martin@heni-online.de>
  */
-class KDE_EXPORT KGameKeyIO : public KGameIO
+class TDE_EXPORT KGameKeyIO : public KGameIO
 {
   TQ_OBJECT
   
@@ -247,7 +247,7 @@ protected:
  *  from a widget and create moves for the player it belongs to.
  *  @author Martin Heni <martin@heni-online.de>
  */
-class KDE_EXPORT KGameMouseIO : public KGameIO
+class TDE_EXPORT KGameMouseIO : public KGameIO
 {
   TQ_OBJECT
   
@@ -323,7 +323,7 @@ protected:
  *  for the definition of the computer player.
  *  @author Martin Heni <martin@heni-online.de>
  */
-class KDE_EXPORT KGameProcessIO : public KGameIO
+class TDE_EXPORT KGameProcessIO : public KGameIO
 {
   TQ_OBJECT
   
@@ -478,7 +478,7 @@ private:
  *
  *  @author  <b_mann@gmx.de>
  */
-class KDE_EXPORT KGameComputerIO : public KGameIO
+class TDE_EXPORT KGameComputerIO : public KGameIO
 {
   TQ_OBJECT
   
