@@ -48,43 +48,43 @@
 #define PROJECTOPTIONS 1
 
 typedef KDevGenericFactory<DoxygenPart> DoxygenFactory;
-static const KDevPluginInfo data("kdevdoxygen");
-K_EXPORT_COMPONENT_FACTORY( libkdevdoxygen, DoxygenFactory( data ) )
+static const KDevPluginInfo pluginData("kdevdoxygen");
+K_EXPORT_COMPONENT_FACTORY( libkdevdoxygen, DoxygenFactory( pluginData ) )
 
 DoxygenPart::DoxygenPart(TQObject *parent, const char *name, const TQStringList &)
-    : KDevPlugin(&data, parent, name ? name : "DoxygenPart"), m_activeEditor(0), m_cursor(0)
+    : KDevPlugin(&pluginData, parent, name ? name : "DoxygenPart"), m_activeEditor(0), m_cursor(0)
 {
     setInstance(DoxygenFactory::instance());
     setXMLFile("kdevdoxygen.rc");
 
     TDEAction *action;
     action = new TDEAction( i18n("Build API Documentation"), 0,
-                          this, TQT_SLOT(slotDoxygen()),
+                          this, TQ_SLOT(slotDoxygen()),
                           actionCollection(), "build_doxygen" );
     action->setToolTip(i18n("Build API documentation"));
     action->setWhatsThis(i18n("<b>Build API documentation</b><p>Runs doxygen on a project Doxyfile to generate API documentation. "
         "If the search engine is enabled in Doxyfile, this also runs doxytag to create it."));
 
     action = new TDEAction( i18n("Clean API Documentation"), 0,
-                          this, TQT_SLOT(slotDoxClean()),
+                          this, TQ_SLOT(slotDoxClean()),
                           actionCollection(), "clean_doxygen" );
     action->setToolTip(i18n("Clean API documentation"));
     action->setWhatsThis(i18n("<b>Clean API documentation</b><p>Removes all generated by doxygen files."));
 
-//    connect( core(), TQT_SIGNAL(projectConfigWidget(KDialogBase*)), this, TQT_SLOT(projectConfigWidget(KDialogBase*)) );
+//    connect( core(), TQ_SIGNAL(projectConfigWidget(KDialogBase*)), this, TQ_SLOT(projectConfigWidget(KDialogBase*)) );
 
 	_configProxy = new ConfigWidgetProxy( core() );
 	_configProxy->createProjectConfigPage( i18n("Doxygen"), PROJECTOPTIONS, info()->icon() );
-	connect( _configProxy, TQT_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
-		this, TQT_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )) );
+	connect( _configProxy, TQ_SIGNAL(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )),
+		this, TQ_SLOT(insertConfigWidget(const KDialogBase*, TQWidget*, unsigned int )) );
 
-    m_actionDocumentFunction = new TDEAction(i18n("Document Current Function"), 0, CTRL+SHIFT+Key_S, this, TQT_SLOT(slotDocumentFunction()), actionCollection(), "edit_document_function");
+    m_actionDocumentFunction = new TDEAction(i18n("Document Current Function"), 0, CTRL+SHIFT+Key_S, this, TQ_SLOT(slotDocumentFunction()), actionCollection(), "edit_document_function");
     m_actionDocumentFunction->setToolTip( i18n("Create a documentation template above a function"));
     m_actionDocumentFunction->setWhatsThis(i18n("<b>Document Current Function</b><p>Creates a documentation template according to a function's signature above a function definition/declaration."));
 
     m_tmpDir.setAutoDelete(true);
-    connect( partController(), TQT_SIGNAL(activePartChanged(KParts::Part*)), this, TQT_SLOT(slotActivePartChanged(KParts::Part* )));
-    m_actionPreview = new TDEAction(i18n("Preview Doxygen Output"), 0, CTRL+ALT+Key_P, this, TQT_SLOT(slotRunPreview()), actionCollection(), "show_preview_doxygen_output");
+    connect( partController(), TQ_SIGNAL(activePartChanged(KParts::Part*)), this, TQ_SLOT(slotActivePartChanged(KParts::Part* )));
+    m_actionPreview = new TDEAction(i18n("Preview Doxygen Output"), 0, CTRL+ALT+Key_P, this, TQ_SLOT(slotRunPreview()), actionCollection(), "show_preview_doxygen_output");
     m_actionPreview->setToolTip( i18n("Show a preview of the Doxygen output of this file") );
     m_actionPreview->setWhatsThis( i18n("<b>Preview Doxygen output</b><p>Runs Doxygen over the current file and shows the created index.html.") );
 
@@ -116,7 +116,7 @@ void DoxygenPart::insertConfigWidget( const KDialogBase * dlg, TQWidget * page,
 		adjustDoxyfile();
 
 		DoxygenConfigWidget *w = new DoxygenConfigWidget(project()->projectDirectory() + "/Doxyfile", page );
-		connect( dlg, TQT_SIGNAL(okClicked()), w, TQT_SLOT(accept()) );
+		connect( dlg, TQ_SIGNAL(okClicked()), w, TQ_SLOT(accept()) );
 	}
 }
 
@@ -474,7 +474,7 @@ void DoxygenPart::slotRunPreview( )
     if (pStyle != 0 && !stylesheet.isNull())
         *pStyle->valueRef() = stylesheet;
 
-    connect(appFrontend, TQT_SIGNAL(processExited()), this, TQT_SLOT(slotPreviewProcessExited()));
+    connect(appFrontend, TQ_SIGNAL(processExited()), this, TQ_SLOT(slotPreviewProcessExited()));
     appFrontend->startAppCommand("", "doxygen \"" + file.name() + "\"", false);
 }
 
