@@ -23,37 +23,6 @@ Boston, MA 02110-1301, USA.
 #define TQT_TQSTYLE_H
 
 #include <tqt.h>
-
-#ifdef USE_QT3
-
-// Reimplement the QStyle class
-// For Qt3, no changes are needed
-
 #include <ntqstyle.h>
 
-#endif // USE_QT3
-
-#ifdef USE_QT4
-
-// Reimplement the QStyle class
-// For Qt4, some changes are needed
-
-#include <tqt4/Qt/ntqstyle.h>
-#include <Qt/q3listview.h>
-#include <tqt4/Qt/qstyleoption.h>
-
-// class TQStyle : public QStyle {
-// public:
-// 	typedef QStyle::StateFlag StyleFlags;
-// 	TQStyle();
-// 	virtual ~TQStyle() {};
-//
-// 	bool isDefault() const;
-//
-// private:
-// 	bool def;
-// };
-
-#endif // USE_QT4
-
 #endif /* TQT_TQSTYLE_H */
