@@ -49,7 +49,7 @@
 # include "ntqregexp.h"
 #endif
 
-#ifdef Q_WS_MAC
+#ifdef TQ_WS_MAC
 #define TQMAC_CTRL  (TQString(TQChar(0x2318)))
 #define TQMAC_META  (TQString(TQChar(0x2303)))
 #define TQMAC_ALT   (TQString(TQChar(0x2325)))
@@ -227,7 +227,7 @@ TQKeySequence::TQKeySequence()
 
     \code
 	TQPopupMenu *file = new TQPopupMenu( this );
-	file->insertItem( tr("&Open..."), this, SLOT(open()),
+	file->insertItem( tr("&Open..."), this, TQ_SLOT(open()),
 			  TQKeySequence( tr("Ctrl+O", "File|Open") ) );
     \endcode
 
