@@ -126,7 +126,7 @@ TQPrinter::TQPrinter( PrinterMode m )
     paper_source = OnlyOne;
     switch ( m ) {
 	case ScreenResolution:
-#ifdef Q_WS_QWS
+#ifdef TQ_WS_QWS
 	    res = 72;
 #else
 	    res = TQPaintDevice::x11AppDpiY();
