@@ -129,6 +129,7 @@ void *TQThreadInstance::start( void *_arg )
 #if defined(QT_USE_GLIBMAINLOOP)
     // This is the first time we have access to the native pthread ID of this newly created thread
     ((TQThreadInstance*)arg[1])->thread_id = pthread_self();
+    pthread_detach(pthread_self());
 #endif // QT_USE_GLIBMAINLOOP
 
 #ifdef QT_DEBUG
@@ -483,7 +484,7 @@ bool TQThread::wait( unsigned long time )
 {
     TQMutexLocker locker( d->mutex() );
 
-    if ( d->thread_id == pthread_self() ) {
+    if ( pthread_equal( d->thread_id, pthread_self() ) ) {
 #ifdef QT_CHECK_STATE
 	tqWarning( "TQThread::wait: thread tried to wait on itself" );
 #endif // QT_CHECK_STATE
