@@ -49,7 +49,7 @@ using std::exit;
 #include <sys/stat.h>
 #include <cassert>
 
-#include <kdemacros.h>
+#include <tdemacros.h>
 
 static const int debugArea = 7122;
 
@@ -80,7 +80,7 @@ static const unsigned int SIEVE_DEFAULT_RECIEVE_BUFFER = 512;
 using namespace TDEIO;
 extern "C"
 {
-	KDE_EXPORT int kdemain(int argc, char **argv)
+	TDE_EXPORT int kdemain(int argc, char **argv)
 	{
 		TDEInstance instance("tdeio_sieve" );
 
