@@ -53,21 +53,21 @@
 extern "C"
 {
    /// application name for libtdescreensaver interface
-   KDE_EXPORT const char *kss_applicationName = "kpendulum.kss";
+   TDE_EXPORT const char *kss_applicationName = "kpendulum.kss";
    /// application description for libtdescreensaver interface
-   KDE_EXPORT const char *kss_description = I18N_NOOP("Simulation of\
+   TDE_EXPORT const char *kss_description = I18N_NOOP("Simulation of\
  a two-part pendulum");
    /// application version for libtdescreensaver interface
-   KDE_EXPORT const char *kss_version = KPENDULUM_VERSION;
+   TDE_EXPORT const char *kss_version = KPENDULUM_VERSION;
 
    /// function to create screen saver object
-   KDE_EXPORT KScreenSaver* kss_create(WId id)
+   TDE_EXPORT KScreenSaver* kss_create(WId id)
    {
       return new KPendulumSaver(id);
    }
 
    /// function to create setup dialog for screen saver
-   KDE_EXPORT TQDialog* kss_setup()
+   TDE_EXPORT TQDialog* kss_setup()
    {
       return new KPendulumSetup();
    }
@@ -379,7 +379,7 @@ KPendulumSaver::KPendulumSaver(WId id) :
    // set up and start cyclic timer
    timer = new TQTimer(this);
    timer->start(deltaT, TRUE);
-   connect(timer, TQT_SIGNAL(timeout()), this, TQT_SLOT(doTimeStep()));
+   connect(timer, TQ_SIGNAL(timeout()), this, TQ_SLOT(doTimeStep()));
 }
 
 KPendulumSaver::~KPendulumSaver()
@@ -754,8 +754,8 @@ KPendulumSetup::KPendulumSetup(TQWidget* parent, const char* name)
    // if the preview area is resized it emmits the resized() event which is
    // caught by the saver.  The embedded GlArea is resized to fit into the
    // preview area.
-   connect(preview, TQT_SIGNAL(resized(TQResizeEvent*)),
-           saver,   TQT_SLOT(resizeGlArea(TQResizeEvent*)));
+   connect(preview, TQ_SIGNAL(resized(TQResizeEvent*)),
+           saver,   TQ_SLOT(resizeGlArea(TQResizeEvent*)));
 }
 
 KPendulumSetup::~KPendulumSetup()
