@@ -980,7 +980,7 @@ NextClientFactory::borderSizes() const
 
 } // KStep namespace
 
-extern "C" KDE_EXPORT KDecorationFactory* create_factory()
+extern "C" TDE_EXPORT KDecorationFactory* create_factory()
 {
     return new KStep::NextClientFactory();
 }
