@@ -2186,7 +2186,7 @@ void tdeio_svnProtocol::wc_resolve( const KURL& wc, bool recurse ) {
 
 extern "C"
 {
-	KDE_EXPORT int kdemain(int argc, char **argv)    {
+	TDE_EXPORT int kdemain(int argc, char **argv)    {
 		TDEInstance instance( "tdeio_kdevsvn" );
 
 		kdDebug(9036) << "*** Starting tdeio_kdevsvn " << endl;
